@@ -14,7 +14,7 @@
 #include <ncurses/ncurses.h>
 #endif
 
-BOOL commands_quit(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_quit(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(saphire_job_num() == 0) {
         gMainLoop = FALSE;
@@ -32,7 +32,7 @@ BOOL commands_quit(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_keycommand(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_keycommand(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 5) {
         char* argv1 = string_c_str(vector_item(argv, 1));
@@ -53,7 +53,7 @@ BOOL commands_keycommand(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* next
     return TRUE;
 }
 
-BOOL commands_keymap(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_keymap(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 12) {
         char keys[kKeyMapKeysMax];
@@ -78,7 +78,7 @@ BOOL commands_keymap(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_cursor_move(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_cursor_move(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -161,6 +161,7 @@ BOOL commands_cursor_move(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nex
         char buf[128];
         sprintf(buf, "cursor_move_hook %d", dir);
         int rcode2 = saphire_shell(buf, "cursor_move_hook", nextout, nextin, nexterr);
+        saphire_sweep();
 
         if(rcode2 < 0) {
             if(mis_raw_mode()) {
@@ -178,7 +179,7 @@ BOOL commands_cursor_move(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nex
     return TRUE;
 }
 
-BOOL commands_mcd(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mcd(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int dir = adir();
     int l;
@@ -241,6 +242,7 @@ BOOL commands_mcd(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
         sprintf(buf, "mcd_hook %d", dir);
 
         int rcode2 = saphire_shell(buf, "mcd_hook", nextout, nextin, nexterr);
+        saphire_sweep();
         if(rcode2 < 0) {
             if(mis_raw_mode()) {
                 merr_msg(string_c_str(gErrMsg));
@@ -258,7 +260,7 @@ BOOL commands_mcd(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_file_name(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_name(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -311,7 +313,7 @@ BOOL commands_file_name(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     return TRUE;
 }
 
-BOOL commands_path(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_path(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -361,7 +363,7 @@ BOOL commands_path(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_file_ext(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_ext(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -415,7 +417,7 @@ BOOL commands_file_ext(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
     return TRUE;
 }
 
-BOOL commands_file_index(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_index(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -467,7 +469,7 @@ BOOL commands_file_index(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* next
     return TRUE;
 }
 
-BOOL commands_file_user(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_user(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -521,7 +523,7 @@ BOOL commands_file_user(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     return TRUE;
 }
 
-BOOL commands_file_group(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_group(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -575,7 +577,7 @@ BOOL commands_file_group(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* next
     return TRUE;
 }
 
-BOOL commands_file_perm(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_perm(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -633,7 +635,7 @@ BOOL commands_file_perm(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     return TRUE;
 }
 
-BOOL commands_file_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_file_num(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -685,7 +687,7 @@ BOOL commands_file_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
     return TRUE;
 }
 
-BOOL commands_dir_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_dir_num(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 1) {
         char buf[BUFSIZ];
@@ -700,7 +702,7 @@ BOOL commands_dir_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_cursor_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_cursor_num(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -753,7 +755,7 @@ BOOL commands_cursor_num(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* next
     return TRUE;
 }
 
-BOOL commands_isearch(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_isearch(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     gISearch = TRUE;
     *rcode = 0;
@@ -761,7 +763,7 @@ BOOL commands_isearch(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_cmdline(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_cmdline(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     BOOL quick = FALSE;
     BOOL continue_ = FALSE;
@@ -811,6 +813,7 @@ BOOL commands_cmdline(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
 
     if(*rcode == 0) {
         int rcode2 = saphire_shell("cmdline_hook", "cursor_move_hook", nextout, nextin, nexterr);
+        saphire_sweep();
 
         if(rcode2 < 0) {
             if(mis_raw_mode()) {
@@ -828,7 +831,7 @@ BOOL commands_cmdline(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_external(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_external(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     BOOL hitanykey = TRUE;
@@ -864,6 +867,7 @@ BOOL commands_external(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
         sRFd* pipein = sRFd_new(STDIN_FILENO);
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         int r = saphire_shell(string_c_str(vector_item(argv, 1)), "run", pipeout, pipein, STDERR_FILENO);
+        saphire_sweep();
         set_signal_mfiler();
         sRFd_delete(pipein);
         sWFd_flash(pipeout);
@@ -903,7 +907,7 @@ BOOL commands_external(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
     return TRUE;
 }
 
-BOOL commands_activate(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_activate(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 2) {
         int n = atoi(string_c_str(vector_item(argv, 1)));
@@ -914,6 +918,7 @@ BOOL commands_activate(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
         sprintf(buf, "activate_hook %d", n);
 
         int rcode2 = saphire_shell(buf, "activate_hook", nextout, nextin, nexterr);
+        saphire_sweep();
 
         if(rcode2 < 0) {
             if(mis_raw_mode()) {
@@ -931,7 +936,7 @@ BOOL commands_activate(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
     return TRUE;
 }
 
-BOOL commands_defmenu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_defmenu(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     /// 引数のチェック ///
     if(vector_size(argv)%3 != 2) {
@@ -957,7 +962,7 @@ BOOL commands_defmenu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_addmenu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_addmenu(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     /// 引数のチェック ///
     if(vector_size(argv)%3 != 2) {
@@ -985,7 +990,7 @@ BOOL commands_addmenu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_menu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_menu(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 2) {
         char* menu_name = string_c_str(vector_item(argv, 1));
@@ -1002,7 +1007,7 @@ BOOL commands_menu(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_reread(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_reread(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1050,7 +1055,7 @@ BOOL commands_reread(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_allfiles(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_allfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1259,7 +1264,7 @@ BOOL commands_allfiles(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin
     return TRUE;
 }
 
-BOOL commands_markfiles(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_markfiles(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1550,7 +1555,7 @@ BOOL commands_markfiles(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     return TRUE;
 }
 
-BOOL commands_mark(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mark(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
 // user group perm
     int l;
@@ -1726,7 +1731,7 @@ BOOL commands_mark(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_new_dir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_new_dir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(vector_size(argv) == 2) {
         char* dir = string_c_str(vector_item(argv, 1));
@@ -1737,7 +1742,7 @@ BOOL commands_new_dir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_del_dir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_del_dir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1784,7 +1789,7 @@ BOOL commands_del_dir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
 
 
 
-BOOL commands_marking(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_marking(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1840,7 +1845,7 @@ BOOL commands_marking(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_mask(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mask(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     int dir = adir();
@@ -1964,7 +1969,7 @@ BOOL commands_mask(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_vd(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_vd(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     filer_vd_start(adir());
     filer_vd_add(adir(), "..");
@@ -1999,7 +2004,7 @@ vd_end:
     return TRUE;
 }
 
-BOOL commands_mrename(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mrename(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
     BOOL reread = FALSE;
@@ -2074,7 +2079,7 @@ BOOL commands_mrename(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_row(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_row(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
     sprintf(buf, "%d", filer_row(adir()));
@@ -2087,7 +2092,7 @@ BOOL commands_row(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_row_max(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_row_max(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
     sprintf(buf, "%d", filer_row_max(adir()));
@@ -2100,7 +2105,7 @@ BOOL commands_row_max(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_line(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_line(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
     sprintf(buf, "%d", filer_line(adir()));
@@ -2114,7 +2119,7 @@ BOOL commands_line(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_line_max(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_line_max(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[BUFSIZ];
     sprintf(buf, "%d", filer_line_max(adir()));
@@ -2143,7 +2148,7 @@ static void draw_progress_box(int mark_num)
     mmvprintw(y+1, (maxx-22)/2+1, "(%d/%d) files", gProgressMark, mark_num);
 }
 
-BOOL commands_mcp(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mcp(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2270,7 +2275,7 @@ BOOL commands_mcp(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_mbackup(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mbackup(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2348,7 +2353,7 @@ BOOL commands_mbackup(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_mmv(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mmv(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2481,7 +2486,7 @@ BOOL commands_mmv(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_mrm(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mrm(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2549,7 +2554,7 @@ BOOL commands_mrm(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_mtrashbox(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mtrashbox(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2689,7 +2694,7 @@ BOOL commands_mtrashbox(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nexti
     return TRUE;
 }
 
-BOOL commands_mln(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mln(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2801,7 +2806,7 @@ BOOL commands_mln(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int
     return TRUE;
 }
 
-BOOL commands_mclear_immediately(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mclear_immediately(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
         merr_msg("invalid terminal setting. not raw mode");
@@ -2814,7 +2819,7 @@ BOOL commands_mclear_immediately(int* rcode, vector_obj* argv, sWFd* nextout, sR
     return TRUE;
 }
 
-BOOL commands_mchoise(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_mchoise(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
 /*
@@ -2854,7 +2859,7 @@ BOOL commands_mchoise(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin,
     return TRUE;
 }
 
-BOOL commands_adir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_adir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[256];
     sprintf(buf, "%d", adir());
@@ -2868,7 +2873,7 @@ BOOL commands_adir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, in
     return TRUE;
 }
 
-BOOL commands_sdir(int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+BOOL commands_sdir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     char buf[256];
     sprintf(buf, "%d", sdir());
